# vocus_sagemaker_utils
> Various functions for processing data for Sagemaker Machine Learning, model training and predictions


This file will become your README and also the index of your documentation.

## Install

`pip install vocus_sagemaker_utils`

## How to use

Fill me in please! Don't forget code examples:

```
1+1
```




    2


